/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-

  Copyright (C) 2002, 2005, 2006  Dmitry V. Levin <ldv@altlinux.org>
  Copyright (C) 2019-2021  Igor Vlasenko <viy@altlinux.org>

  The Window Manager's Selector common header.

  This file is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
*/

#define WM_LIST_DEBIAN_WM_SESSION 11
#define WM_LIST_XDG_WM_SESSION 22

#define WM_XDG_X_SESSION_FLAG 2
#define WM_XDG_WAYLAND_SESSION_FLAG 4

extern int wm_list_mode;
extern int wm_xdg_use_x;
extern int wm_xdg_use_wayland;
extern int verbose;

#define VERBOSE_WARNING (verbose > 0)
#define VERBOSE_INFO (verbose > 1)
#define VERBOSE_DEBUG (verbose > 2)

extern int print_only;
extern int save_prefs;

extern const char *saved;

#define WM_ENTRY_FLAG_DEFAULT 1
#define WM_ENTRY_FLAG_PREFERRED 2
#define WM_ENTRY_FLAG_SAVED 4
#define WM_ENTRY_FLAG_FAILSAFE 8
#define WM_ENTRY_FLAG_REMOVE 16

typedef struct
{
	char   *file;
	char   *wmfile;
	char   *name;
	char   *wmname;
	char   *type;
	char   *icon;
	char   *exec;
	char   *wmexec;
	char   *try_exec;
	char   *hidden;
	char   *xdg_current_session;
	/* fields with _ should not be freed.
	   They point to memory allocated for fields above. */
	char   *_basename;
	char   *_runwmid;
//	char   *_wmlabel;
	int     priority;
	int     flags;
}
wm_entry;

typedef struct
{
	size_t  total;
	size_t  allocated;
	wm_entry  *entry_list;
}
wm_entry_list_header;

extern const wm_entry *wm_entry_default;
extern const wm_entry *wm_entry_saved;
extern const wm_entry *wm_entry_selected;
extern const wm_entry *wm_entry_failsafe;

extern void ExecSaved();
extern void ExecSelected();
extern void ReadProgramConfig();
extern void FreeWMEntry(wm_entry* entry);
extern void ExecWMEntry(const wm_entry *entry);
extern size_t GetWMEntryListTotal(wm_entry_list_header *header);
extern wm_entry_list_header PrepareWMEntryList();
